@@ -2,17 +2,16 @@ import requests
 import setuptools
 import sys, os
 dev_pkg_name = "openapi-server-dev"
-# data = requests.get(f"https://pypi.org/pypi/{dev_pkg_name}/json").json()
-# latest_version = [1, 0, 0]
-# for version in data["releases"]:
-#     version_lst = [int(num) for num in version.split(".")]
-#     if version_lst > latest_version:
-#         latest_version = version_lst
-# new_version = latest_version
-# new_version[2] += 1
-# new_version = [str(num) for num in new_version]
-# new_version = ".".join(new_version)
-new_version = "1.0.0"
+data = requests.get(f"https://pypi.org/pypi/{dev_pkg_name}/json").json()
+latest_version = [1, 0, 0]
+for version in data["releases"]:
+    version_lst = [int(num) for num in version.split(".")]
+    if version_lst > latest_version:
+        latest_version = version_lst
+new_version = latest_version
+new_version[2] += 1
+new_version = [str(num) for num in new_version]
+new_version = ".".join(new_version)
 openapi_modules = setuptools.find_packages("openapi_server")
 # provide full path for the modules
 openapi_modules = ["openapi_server." + module for module in openapi_modules]
